Crate tuna
Source - impl_tuneable
- impl_tuneable_simple
- Boolean
- The definition of a boolean variable
- Float32
- The definition of a float variable
- Float64
- The definition of a float variable
- Int32
- The definition of a float variable
- Int64
- The definition of a float variable
- Tuneable
- AsTuneable
- Implemented by types that can be used to make tuneables; i.e., manipulated state with various constraints
- get
- Get a the value of tunable variable, if it matches the expected type
- is_registered
- Check if the value is registered
- register
- Register a tuneable variable with a default variable. If variable
already exists, won’t do anything.
- reset
- Reset the variable to default value
- set
- Set a tuneable variable, if it makes the expected type
- TunaState
- tuna